<!--

@license Apache-2.0

Copyright (c) 2022 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# cartesianProduct

> Return the [Cartesian product][cartesian-product].

<section class="usage">

## Usage

```javascript
var cartesianProduct = require( '@stdlib/array/base/cartesian-product' );
```

#### cartesianProduct( x1, x2 )

Returns the [Cartesian product][cartesian-product].

```javascript
var x1 = [ 1, 2, 3 ];
var x2 = [ 4, 5 ];

var out = cartesianProduct( x1, x2 );
// returns [ [ 1, 4 ], [ 1, 5 ], [ 2, 4 ], [ 2, 5 ], [ 3, 4 ], [ 3, 5 ] ]
```

If provided one or more empty arrays, the function returns an empty array.

```javascript
var x1 = [ 1, 2, 3, 4 ];
var x2 = [];

var out = cartesianProduct( x1, x2 );
// returns []
```

</section>

<!-- /.usage -->

<section class="notes">

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var linspace = require( '@stdlib/array/base/linspace' );
var cartesianProduct = require( '@stdlib/array/base/cartesian-product' );

var x1 = linspace( 0, 5, 6 );
var x2 = linspace( 10, 15, 6 );

var out = cartesianProduct( x1, x2 );
// returns [ [ 0, 10 ], [ 0, 11 ], ..., [ 5, 14 ], [ 5, 15 ] ]
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[cartesian-product]: https://en.wikipedia.org/wiki/Cartesian_product

</section>

<!-- /.links -->
