/**
* @license Apache-2.0
*
* Copyright (c) 2023 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Generate a linearly spaced numeric array whose elements increment by 1 starting from one.
*
* @module @stdlib/array/base/one-to
*
* @example
* var oneTo = require( '@stdlib/array/base/one-to' );
*
* var arr = oneTo( 6 );
* // returns [ 1, 2, 3, 4, 5, 6 ]
*
* @example
* var oneTo = require( '@stdlib/array/base/one-to' );
*
* var out = [ 0, 0, 0, 0, 0, 0 ];
* var arr = oneTo.assign( out, 1, 0 );
* // returns [ 1, 2, 3, 4, 5, 6 ]
*
* var bool = ( out === arr );
* // returns true
*/

// MODULES //

var setReadOnly = require( '@stdlib/utils/define-nonenumerable-read-only-property' );
var main = require( './main.js' );
var assign = require( './assign.js' );


// MAIN //

setReadOnly( main, 'assign', assign );


// EXPORTS //

module.exports = main;
