<!--

@license Apache-2.0

Copyright (c) 2023 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# toAccessorArray

> Convert an array-like object to a minimal array-like object supporting the accessor protocol.

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- Package usage documentation. -->

<section class="usage">

## Usage

```javascript
var toAccessorArray = require( '@stdlib/array/base/to-accessor-array' );
```

#### toAccessorArray( arr )

Converts an array-like object to a minimal array-like object supporting the accessor protocol.

```javascript
var arr1 = [ 1, 2, 3 ];

var arr2 = toAccessorArray( arr1 );
// returns <AccessorArray>

var v = arr2.get( 1 );
// returns 2

var bool = ( arr2 === arr1 );
// returns false
```

If the provided array-like object already supports the accessor protocol, the function returns the input array unchanged.

```javascript
var Complex128Array = require( '@stdlib/array/complex128' );

var arr1 = new Complex128Array( 10 );
// returns <Complex128Array>

var arr2 = toAccessorArray( arr1 );
// returns <Complex128Array>

var bool = ( arr2 === arr1 );
// returns true
```

</section>

<!-- /.usage -->

<!-- Package usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<!-- Package usage examples. -->

<section class="examples">

* * *

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var Complex128Array = require( '@stdlib/array/complex128' );
var toAccessorArray = require( '@stdlib/array/base/to-accessor-array' );

// Define a function for printing the contents of an array and which assumes accessor protocol support:
function printArray( name, x ) {
    var i;
    for ( i = 0; i < x.length; i++ ) {
        console.log( '%s[%d] = %s', name, i, x.get( i ).toString() );
    }
}

// Create an array of complex numbers:
var buf = [ 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0 ];
var cmplx = new Complex128Array( buf );

// Create an array of the real components:
var real = [ 0, 0, 1, 2, 0, 0, 0, 0, 3, 0 ];

// Ensure the arrays support the accessor protocol to allow for uniform iteration:
cmplx = toAccessorArray( cmplx );
real = toAccessorArray( real );

// Print the contents of each array:
printArray( 'complx', cmplx );
printArray( 'real', real );
```

</section>

<!-- /.examples -->

<!-- Section to include cited references. If references are included, add a horizontal rule *before* the section. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="references">

</section>

<!-- /.references -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

</section>

<!-- /.links -->
