/*
* @license Apache-2.0
*
* Copyright (c) 2022 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

import realarray = require( './index' );


// TESTS //

// The function returns a typed array..
{
	realarray(); // $ExpectType TypedArray
	realarray( 'float32' ); // $ExpectType TypedArray
	realarray( 10, 'float32' ); // $ExpectType TypedArray
	realarray( [ 1, 2, 3 ], 'int32' ); // $ExpectType TypedArray
}

// The compiler throws an error if the function is provided a first argument which is not a data type, number, array-like object, or typed array...
{
	realarray( true ); // $ExpectError
	realarray( false ); // $ExpectError
	realarray( {} ); // $ExpectError
	realarray( null ); // $ExpectError
	realarray( ( x: number ): number => x ); // $ExpectError
}

// The compiler throws an error if the function is provided an unsupported number of arguments...
{
	const buf = new ArrayBuffer( 32 );
	realarray( buf, 8, 2, 'int32', {} ); // $ExpectError
}
